#!/usr/bin/env python2
import os

def parse_host(host):
  h = host.split(':')
  host = h[0]
  if host.startswith('(') and host.endswith(')'):
    host = host[1:-1]
  if host.endswith('.'): host += 'com'
  if host.endswith('.c'): host += 'om'
  if host.endswith('.co'): host += 'm'
  h[0] = host
  return ':'.join(h)

# 1 - device (eg ttyr0), 2 - user or place, 3 - panel port, 4 - node name
# 5 - node port, 6 - EDX directory, 7 - screen dump printer, 8 - label prtr
# 9 - number of windows, 10... - EDX Terminal names
def read_old_config(fp):
  for ln in fp:
    ln = ln.strip()
    if ln.startswith('#'): continue
    a = ln.split()
    tty,usr,port,host,hport,edxdir,scrdmp,label,nwin = a[:9]
    terms = a[9:]
    if usr.startswith('='):
      key = usr[1:]
    else: key = ''
    if host.startswith('='):
      key += '@' + parse_host(host[1:])
    if tty.startswith('='):
      if key: key += ','
      key += 'tty=%s' % tty[1:]
    print '%s%s%s\t%s\t%s' % (key,'\t'*(4-len(key)/8),
    	edxdir,scrdmp,' '.join(terms))

def find_config(fp):
  env = os.environ
  try: user = env['LOGUSER']
  except KeyError: user = None
  tty  = env['LOGTTY']
  try: node = parse_host(env['LOGNODE'])
  except KeyError: node = None
  try: win  = env['WINID']
  except KeyError: win = None
  for ln in fp:
    ln = ln.strip()
    if ln.startswith('#'): continue
    a = ln.split()
    if len(a) < 4: continue
    key,edxdir,scrdmp = a[0:3]
    terms = a[3:]
    for f in key.split(','):
      if f.startswith('tty=') and f[4:] != tty: break
      a = f.split('@',1)
      if user and a[0] and a[0] != user: break
      if node != None and len(a) > 1 and a[1] != node: break
    else:
      print ln
      break

if __name__ == '__main__':
  import sys
  if len(sys.argv) != 2:
    print >>sys.stderr,'Usage: runedx.py configfile'
    sys.exit(1)
  fname = sys.argv[1]
  fp = open(fname,'r')
  if fname.endswith('.conf'):
    find_config(fp)
  else:
    read_old_config(fp)
